<?php
/**
 * The Template for displaying all single products
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/single-product.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see         https://docs.woocommerce.com/document/template-structure/
 * @package     WooCommerce\Templates
 * @version     1.6.4
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

global $post;

$page_id = 0;
if (is_object($post) && (is_single() || is_page() || is_front_page()) ) {
	$page_id = $post->ID;
}

$page_id = apply_filters('tmm_post_id', $page_id);

if (is_object($post) && empty_content($post->post_content) && is_page_template('default')) {
	$page_content = ' has-no-content';
} else {
	$page_content = ' has-content';
}

get_header( 'shop' ); ?>

<div id="content" class="<?php echo tmm_get_sidebar_position() ?>">

<?php tmm_layout_content($page_id, 'before_full_width'); ?>

	<div class="container">
	<div class="row">

<?php if ( tmm_get_sidebar_position() == 'no_sidebar' ) { ?>
	<main id="main" class="col-xs-12<?php echo esc_attr( $page_content ) ?>">
<?php } ?>

<?php if ( tmm_get_sidebar_position() != 'no_sidebar' ) { ?>
	<main id="main" class="col-md-9 col-sm-12<?php echo esc_attr( $page_content ) ?>">
<?php } ?>

	<!-- - - - - - - - - - - - Entry - - - - - - - - - - - - - - -->

	<?php
		/**
		 * woocommerce_before_main_content hook.
		 *
		 * @hooked woocommerce_output_content_wrapper - 10 (outputs opening divs for the content)
		 * @hooked woocommerce_breadcrumb - 20
		 */
		do_action( 'woocommerce_before_main_content' );
	?>

		<?php while ( have_posts() ) : ?>
			<?php the_post(); ?>

			<?php wc_get_template_part( 'content', 'single-product' ); ?>

		<?php endwhile; // end of the loop. ?>

	<?php
		/**
		 * woocommerce_after_main_content hook.
		 *
		 * @hooked woocommerce_output_content_wrapper_end - 10 (outputs closing divs for the content)
		 */
		do_action( 'woocommerce_after_main_content' );
	?>

	<?php
		/**
		 * woocommerce_sidebar hook.
		 *
		 * @hooked woocommerce_get_sidebar - 10
		 */
		do_action( 'woocommerce_sidebar' );
	?>

		<!-- - - - - - - - - - - - end Entry - - - - - - - - - - - - - - -->

		<?php if (tmm_get_sidebar_position() != 'no_sidebar'):  ?>

	</main><!--/ .col-md-9 .col-sm-12 main #main -->

	<?php
	$is_single_car = false;
	if (is_single()) {
		if (get_post_type($post->ID) == TMM_Ext_PostType_Car::$slug) {
			$is_single_car = true;
			get_sidebar('single-car');
		}
	}

	if (!empty($_POST['template_user_cars']) && ($_POST['template_user_cars'] == true)) {
		get_sidebar('user-cars');
	} else {
		if (!empty($_POST['template_user_dealer']) && ($_POST['template_user_dealer'] == true)) {
			if (TMM::get_option('cars_show_statistic_dealer_page', TMM_APP_CARDEALER_PREFIX)) {
				get_sidebar('user-dealer');
			}
		}
		if (!$is_single_car) {
			get_sidebar();
		}
	}
	?>

	<?php endif; ?>

		<?php if (tmm_get_sidebar_position() == 'no_sidebar'): ?>
	</main><!--/ .col-xs-12 #main -->
	<?php endif; ?>

	</div><!--/ .row-->
	</div><!--/ .container-->

	<?php
	if (is_single() || is_page() || is_page_template()) {
		tmm_layout_content($post->ID, 'full_width');
	}
	?>

</div><!--/ #content-->

<?php
get_footer( 'shop' );

/* Omit closing PHP tag at the end of PHP files to avoid "headers already sent" issues. */
